@@ -8,16 +8,24 @@ import time
 import logging
 import signal
 
+from pyfiglet import Figlet
+
+
 
 def print_header():
-    print(Fore.WHITE + 'Starting Janet...')
-    print(Fore.GREEN + 'Janet is running, use the command line to issue commands like:')
-    print(Fore.RED+ '	1. run (to run the selected entry point (running again will kill the current python process)')
-    print(Fore.RED+ '	1. install <PACKAGE_1> <PACKAGE_2> ... (install packages manually)')
-    print(Fore.RED+ '	2. change-entrypoint (change the entry point')
-    print(Fore.RED+ '	3. kill (to manually end a run)')
-    print(Fore.RED+ '	4. exit (to stop janet)')
-    print(Fore.RED+ '	5. menu')
+	f = Figlet(font='slant')
+	print(f.renderText('JANET'))
+	print_cmd()
+
+def print_cmd():
+    print(Fore.WHITE + 'Cool stuff you could do:')
+    print(Fore.GREEN+ '	1. run (to run the selected entry point, running again will kill the current python process)')
+    print(Fore.GREEN+ '	1. install <PACKAGE_1> <PACKAGE_2> ... (install packages manually)')
+    print(Fore.GREEN+ '	2. change-entrypoint (change the script that janet will run)')
+    print(Fore.GREEN+ '	3. kill (to manually end a run)')
+    print(Fore.GREEN+ '	4. exit (to stop janet)')
+    print(Fore.GREEN+ '	5. menu')
+    print(Fore.GREEN+ '	\nUse TAB to autocomplete commands')
     print(Fore.WHITE)
 
 
@@ -69,7 +77,7 @@ def command(command, process, entry_point, project_path):
 		return None, entry_point
 
 	elif command_no_spaces.lower() == 'menu':
-		print_header()
+		print_cmd()
 		return process, entry_point
 
 	else:
